/**
  *  \file client/chart/distancemode.h
  *  \brief Starchart mode: Distance
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_CHART_DISTANCEMODE_H
#define PCC_V2_CLIENT_CHART_DISTANCEMODE_H

#include "client/chartmode.h"
#include "game/coord.h"

/** Distance mode. Display distance between two points on map. */
class WDistanceChartMode : public WSimpleChartMode {
    GPoint origin;
    int    ship_id;

    enum Mode {
        /* Regular distance mode: not locked at a ship */
        DistanceMode,
        /* Waypoint mode: origin is a ship which we play, and
           we allow to change its waypoint. */
        WaypointMode,
        /* Foreign mode: origin is a ship we do not play. */
        ForeignMode,
        /* Other ship mode: we have a ship, but origin is not
           its location, or we don't play it. */
        OtherMode
    };
    Mode getMode() const;

 public:
    WDistanceChartMode(GPoint origin, int ship_id);
    ~WDistanceChartMode();

    bool handleEvent(const UIEvent& event, GChartLocation& loc);
    void drawOverlays(GfxCanvas& can, GChartLocation& loc);
    void drawCursor(GfxCanvas& can, GChartLocation& loc);
    void onMove(GChartLocation& loc);
};

#endif
