/**
  *  \file client/widgets/configedit.h
  *  \brief WConfigEditor widget
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_CONFIGEDIT_H
#define PCC_V2_CLIENT_WIDGETS_CONFIGEDIT_H

#include "ui/ui.h"
#include "ui/widgets/button.h"

class Config;

/** Configuration editor widget. Displays name and value of a configuration
    option, and allows users to edit it. The actual editing happens in a
    WConfigEditor::Editor descendant. */
class WConfigEditor : public UIWidget {
 public:
    class Editor;

    WConfigEditor();
    ~WConfigEditor();

    void set(string_t name, Editor* editor, string_t arg);

    void getLayoutInfo(LayoutInfo& li);
    void drawContent(GfxCanvas& can);
    void onResize(GfxRect oldSize, bool byLayout);

    Signal0 sig_change;

 private:
    UIButton btn_edit;
    string_t name;
    Editor* editor;
    string_t arg;

    void init();
    void onEdit();
};

/** Configuration option editor. Used by WConfigEditor to perform the actual
    editing. To allow re-using a WConfigEditor instance to edit multiple
    options, this class's methods take a string argument, by convention a
    configuration option name. */
class WConfigEditor::Editor : public Object {
 public:
    /** Convert an option's value to a string, for display.
        \param arg String argument */
    virtual string_t toString(string_t arg) = 0;
    /** Edit an option's value.
        \param arg String argument */
    virtual void edit(string_t arg) = 0;
};

/** Simple stupid implementation of WConfigEditor::Editor to edit a
    configuration option. */
class WConfigOptionEditor : public WConfigEditor::Editor {
 public:
    WConfigOptionEditor(Config& cfg);
    string_t toString(string_t arg);
    void edit(string_t arg);

 private:
    Config& cfg;
};

#endif
