/**
  *  \file client/widgets/imagepanel.cc
  *  \brief Image Panel
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/imagepanel.h"
#include "ui/uiglobal.h"
#include "ui/layout.h"
#include "gfx/palette.h"

static const UIColorSet ip_colors = {
    COLOR_SHIELD+14,            // static
    COLOR_GREEN,                // green
    COLOR_YELLOW,               // yellow
    COLOR_RED,                  // red
    COLOR_WHITE,                // white
    COLOR_SHIELD+14,            // contrast
    COLOR_GRAY,                 // input
    COLOR_BLUEGRAY,             // blue
    COLOR_SHIELD+9,             // faded
    COLOR_SHIELD+15,            // heading
    COLOR_YELLOW,               // selection
    COLOR_BLACK,                // invstatic
    COLOR_BLACK,                // background
    COLOR_SHIELD+4,             // link
    COLOR_SHIELD+8,             // link shade
    COLOR_SHIELD+11,            // link focus
    { }
};


/** Constructor.
    \param name  Name (heading) of this screen
    \param image Image to display in background. Can be null. */
WImagePanel::WImagePanel(string_t name, Ptr<GfxPixmap> image)
    : UILayoutableWidget(UIHBoxLayout::instance5),
      UISkin(ip_colors),
      name(name),
      image(image)
{
    setSkin(*this);
}

WImagePanel::~WImagePanel()
{ }

void
WImagePanel::drawContent(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_TITLE_BOLD]);
    ctx.setColor(UIColor::tc_Heading);

    drawBackground(ctx, getExtent());
    outText(ctx, extent.x + 5, extent.y + 5, name);

    can.update(extent);
}

void
WImagePanel::adjustSize(GfxRect& size, bool to_inner)
{
    int factor = to_inner ? -1 : +1;
    int text_height = name.size() ? font_heights[FONT_TITLE] + 5 : 0;

    size.x -= factor*5;
    size.y -= factor*(5 + text_height);
    size.w += factor*10;
    size.h += factor*(10 + text_height);
}

void
WImagePanel::drawBackground(GfxContext& ctx, GfxRect area)
{
    if (image) {
        image->blit(ctx.getCanvas(),
                    area.x, area.y,
                    GfxRect(area.x - extent.x,
                            area.y - extent.y,
                            area.w,
                            area.h));
    } else {
        UISkin::drawBackground(ctx, area);
    }
}
